@@ -23,8 +23,23 @@ use crate::{
     synth::WaveformSynth,
 };
 
-const DEFAULT_SAMPLE_RATE_U32: u32 = 44100;
-pub const DEFAULT_SAMPLE_RATE: f64 = DEFAULT_SAMPLE_RATE_U32 as f64;
+pub fn get_output_stream_params(
+    output_buffer_size: u32,
+    sample_rate_hz: Option<u32>,
+) -> (Device, StreamConfig, SampleFormat) {
+    let device = cpal::default_host().default_output_device().unwrap();
+    let default_config = device.default_output_config().unwrap();
+    let used_config = create_stream_config(
+        "output",
+        &default_config,
+        output_buffer_size,
+        sample_rate_hz.map(SampleRate),
+    );
+
+    println!("[INFO] Using sample rate {} Hz", used_config.sample_rate.0);
+
+    (device, used_config, default_config.sample_format())
+}
 
 pub struct AudioOptions {
     pub audio_in_enabled: bool,
@@ -42,6 +57,7 @@ pub struct AudioModel<S> {
     #[allow(dead_code)]
     input_stream: Option<Stream>,
     updates: Sender<UpdateFn<S>>,
+    sample_rate_hz: u32,
     wav_file_prefix: String,
 }
 
@@ -49,6 +65,7 @@ impl<S: Eq + Hash + Send + 'static> AudioModel<S> {
     pub fn new(
         fluid_synth: FluidSynth,
         waveform_synth: WaveformSynth<S>,
+        output_stream_params: (Device, StreamConfig, SampleFormat),
         options: AudioOptions,
         reverb_options: ReverbOptions,
         delay_options: DelayOptions,
@@ -57,17 +74,21 @@ impl<S: Eq + Hash + Send + 'static> AudioModel<S> {
         let (send, recv) = mpsc::channel();
         let (prod, cons) = RingBuffer::new(options.exchange_buffer_size * 2).split();
 
+        let sample_rate = output_stream_params.1.sample_rate;
+        let sample_rate_hz_u32 = sample_rate.0;
+        let sample_rate_hz_f64 = f64::from(sample_rate_hz_u32);
+
         let audio_out = AudioOut {
             renderer: AudioRenderer {
                 buffer: vec![0.0; usize::try_from(options.output_buffer_size).unwrap() * 4],
                 waveform_synth,
                 fluid_synth,
                 reverb: (
-                    SchroederReverb::new(reverb_options, DEFAULT_SAMPLE_RATE),
+                    SchroederReverb::new(reverb_options, sample_rate_hz_f64),
                     false,
                 ),
-                delay: (Delay::new(delay_options, DEFAULT_SAMPLE_RATE), false),
-                rotary: (Rotary::new(rotary_options, DEFAULT_SAMPLE_RATE), false),
+                delay: (Delay::new(delay_options, sample_rate_hz_f64), false),
+                rotary: (Rotary::new(rotary_options, sample_rate_hz_f64), false),
                 current_wav_writer: None,
                 exchange_buffer: cons,
             },
@@ -79,11 +100,12 @@ impl<S: Eq + Hash + Send + 'static> AudioModel<S> {
         };
 
         Self {
-            output_stream: audio_out.start_stream(options.output_buffer_size),
+            output_stream: audio_out.start_stream(output_stream_params),
             input_stream: options
                 .audio_in_enabled
-                .then(|| audio_in.start_stream(options.input_buffer_size)),
+                .then(|| audio_in.start_stream(options.input_buffer_size, sample_rate)),
             updates: send,
+            sample_rate_hz: sample_rate_hz_u32,
             wav_file_prefix: options.wav_file_prefix,
         }
     }
@@ -121,7 +143,7 @@ impl<S: Eq + Hash + Send + 'static> AudioModel<S> {
 
     pub fn set_recording_active(&self, recording_active: bool) {
         if recording_active {
-            let wav_writer = create_wav_writer(&self.wav_file_prefix);
+            let wav_writer = create_wav_writer(self.sample_rate_hz, &self.wav_file_prefix);
             self.update(move |renderer| {
                 renderer.current_wav_writer = Some(wav_writer);
                 renderer.reverb.0.mute();
@@ -144,13 +166,13 @@ struct AudioOut<S> {
 }
 
 impl<S: Eq + Hash + Send + 'static> AudioOut<S> {
-    fn start_stream(self, output_buffer_size: u32) -> Stream {
-        let device = cpal::default_host().default_output_device().unwrap();
-        let default_config = device.default_output_config().unwrap();
-        let used_config = create_stream_config("output", &default_config, output_buffer_size);
-        let stream = match default_config.sample_format() {
-            SampleFormat::F32 => self.create_stream::<f32>(&device, &used_config),
-            SampleFormat::I16 => self.create_stream::<i16>(&device, &used_config),
+    fn start_stream(
+        self,
+        (device, stream_config, sample_format): (Device, StreamConfig, SampleFormat),
+    ) -> Stream {
+        let stream = match sample_format {
+            SampleFormat::F32 => self.create_stream::<f32>(&device, &stream_config),
+            SampleFormat::I16 => self.create_stream::<i16>(&device, &stream_config),
             SampleFormat::U16 => panic!("U16 sample format not supported"),
         };
         stream.play().unwrap();
@@ -228,10 +250,15 @@ struct AudioIn {
 }
 
 impl AudioIn {
-    fn start_stream(self, input_buffer_size: u32) -> Stream {
+    fn start_stream(self, input_buffer_size: u32, sample_rate: SampleRate) -> Stream {
         let device = cpal::default_host().default_input_device().unwrap();
         let default_config = device.default_input_config().unwrap();
-        let used_config = create_stream_config("input", &default_config, input_buffer_size);
+        let used_config = create_stream_config(
+            "input",
+            &default_config,
+            input_buffer_size,
+            Some(sample_rate),
+        );
         let stream = match default_config.sample_format() {
             SampleFormat::F32 => self.create_stream::<f32>(&device, &used_config),
             SampleFormat::I16 => self.create_stream::<i16>(&device, &used_config),
@@ -257,14 +284,15 @@ impl AudioIn {
 
 fn create_stream_config(
     stream_type: &str,
-    config: &SupportedStreamConfig,
+    default_config: &SupportedStreamConfig,
     buffer_size: u32,
+    sample_rate: Option<SampleRate>,
 ) -> StreamConfig {
     println!(
         "[DEBUG] Default {} stream config:\n{:#?}",
-        stream_type, config
+        stream_type, default_config
     );
-    let buffer_size = match config.buffer_size() {
+    let buffer_size = match default_config.buffer_size() {
         SupportedBufferSize::Range { .. } => BufferSize::Fixed(buffer_size),
         SupportedBufferSize::Unknown => {
             println!("[WARNING] Cannot set buffer size on {} audio device. The device's default buffer size will be used.", stream_type);
@@ -274,12 +302,12 @@ fn create_stream_config(
 
     StreamConfig {
         channels: 2,
-        sample_rate: SampleRate(DEFAULT_SAMPLE_RATE_U32),
+        sample_rate: sample_rate.unwrap_or_else(|| default_config.sample_rate()),
         buffer_size,
     }
 }
 
-fn create_wav_writer(file_prefix: &str) -> WavWriter<BufWriter<File>> {
+fn create_wav_writer(sample_rate_hz: u32, file_prefix: &str) -> WavWriter<BufWriter<File>> {
     let output_file_name = format!(
         "{}_{}.wav",
         file_prefix,
@@ -287,7 +315,7 @@ fn create_wav_writer(file_prefix: &str) -> WavWriter<BufWriter<File>> {
     );
     let spec = WavSpec {
         channels: 2,
-        sample_rate: DEFAULT_SAMPLE_RATE_U32,
+        sample_rate: sample_rate_hz,
         bits_per_sample: 32,
         sample_format: hound::SampleFormat::Float,
     };
